@@ -69,12 +69,10 @@ def attack(event=0):
 	global cur_button
 	if g.cur_mon_hp > 0 and g.hp > 0:
 		attack_monster()
-	else: cur_button = 1
 	if g.cur_mon_hp > 0 and g.hp > 0:
 		attack_player()
-	else: cur_button = 1
-	refresh()
-	refresh_buttons()
+		refresh()
+		refresh_buttons()
 
 #attack the monster
 def attack_monster():
@@ -89,7 +87,7 @@ def attack_monster():
 		#you kill it?
 		if g.cur_mon_hp <= 0:
 			monster_dead()
-			#return 0
+			return 0
 	else:
 		main.print_message("You miss the " + g.monster[mon_index][0] + ".")
 
@@ -137,8 +135,10 @@ def monster_dead():
 			action.activate_line(g.xgrid, g.ygrid, g.zgrid, i)
 
 	#formatting
-	refresh()
-
+	#refresh()
+	window_battle.destroy()
+	global did_run
+	did_run = 0
 
 #run/leave/quit button was pressed
 def runaway():
@@ -446,7 +446,9 @@ def key_handler(key_name):
 			except IndexError: pass
 
 	elif (key_name == "return"):
-		if (cur_button == 0): attack()
+		if (cur_button == 0):
+			attack()
+			return 0
 		elif (cur_button == 1):
 			runaway()
 			return 0
