@@ -84,7 +84,8 @@ def wear_item():
 		g.equip[item_loc] = item_value
 		g.drop_inv_item(item_num[0])
 		g.take_inv_item(temp)
-		main.print_message("You wear your " + g.item[g.equip[item_loc]][0])
+		main.print_message("You equip yourself with your " + 
+			g.item[g.equip[item_loc]][0] + ".")
 		refresh_inv()
 
 #drops an item from the inventory. Uses the
