@@ -420,7 +420,8 @@ def init_window_main(new_game = 0):
 	refreshmap()
 	window_main.wm_geometry("+%d+%d" % (10, 10))
 	window_main.focus()
-	window_main.resizable(width=0, height=0)
+	window_main.resizable(0, 0)
+	window_main.maxsize(1000, 10000)
 	window_main.title(g.game_name)
 	global free_move
 	free_move = 0
