@@ -37,8 +37,10 @@ class map:
 		self.per_tile_info = [] #unused after load
 
 		#grab the needed data from the file
+		if mapname == "": return
 		map_loc = g.mod_directory + "/data/maps/" + mapname
-		map_file = open(map_loc, 'r')
+		try: map_file = open(map_loc, 'r')
+		except IOError: return
 
 		#go through all lines of the file up to ":def"
 		map_line = map_file.readline()
@@ -152,10 +154,8 @@ class map:
 
 					elif tilemode == 0: #onload
 						self.per_tile_info[len(self.per_tile_info)-1][2].append(map_command)
-#						self.field[curr_y][curr_x].onload.append(map_command)
 					else: #action
 						self.per_tile_info[len(self.per_tile_info)-1][3].append(map_command)
-#						self.field[curr_y][curr_x].action.append(map_command)
 					map_line = map_file.readline()
 				continue
 
